@@ -1,14 +1,16 @@
 package Perinci::Sub::Property::curry;
 
-use 5.010;
+our $DATE = '2016-02-23'; # DATE
+our $VERSION = '0.05'; # VERSION
+
+use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
+use Data::Dmp;
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.04'; # VERSION
-
 declare_property(
     name => 'curry',
     type => 'function',
@@ -30,8 +32,7 @@ declare_property(
                 $self->_errif(400, "\"Argument $an has been set by curry\"",
                               'exists($args{\''.$an.'\'})');
                 $self->push_lines(
-                    '$args{\''.$an.'\'} = '.
-                        Perinci::Sub::Wrapper::__squote($av).';');
+                    '$args{\''.$an.'\'} = '.dmp($av).';');
             }
         },
     },
@@ -40,17 +41,19 @@ declare_property(
 1;
 # ABSTRACT: Set arguments for function
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perinci::Sub::Property::curry - Set arguments for function
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Perinci::Sub::Property::curry (from Perl distribution Perinci-Sub-Property-curry), released on 2016-02-23.
 
 =head1 SYNOPSIS
 
@@ -67,30 +70,35 @@ version 0.04
 
 This property sets arguments for function.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Property-curry>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Property-curry>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Property-curry>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Perinci>
 
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
